You can subscribe to this list here.
| 2002 |
Jan
|
Feb
|
Mar
|
Apr
|
May
|
Jun
|
Jul
|
Aug
|
Sep
(1) |
Oct
(122) |
Nov
(152) |
Dec
(69) |
|---|---|---|---|---|---|---|---|---|---|---|---|---|
| 2003 |
Jan
(6) |
Feb
(25) |
Mar
(73) |
Apr
(82) |
May
(24) |
Jun
(25) |
Jul
(10) |
Aug
(11) |
Sep
(10) |
Oct
(54) |
Nov
(203) |
Dec
(182) |
| 2004 |
Jan
(307) |
Feb
(305) |
Mar
(430) |
Apr
(312) |
May
(187) |
Jun
(342) |
Jul
(487) |
Aug
(637) |
Sep
(336) |
Oct
(373) |
Nov
(441) |
Dec
(210) |
| 2005 |
Jan
(385) |
Feb
(480) |
Mar
(636) |
Apr
(544) |
May
(679) |
Jun
(625) |
Jul
(810) |
Aug
(838) |
Sep
(634) |
Oct
(521) |
Nov
(965) |
Dec
(543) |
| 2006 |
Jan
(494) |
Feb
(431) |
Mar
(546) |
Apr
(411) |
May
(406) |
Jun
(322) |
Jul
(256) |
Aug
(401) |
Sep
(345) |
Oct
(542) |
Nov
(308) |
Dec
(481) |
| 2007 |
Jan
(427) |
Feb
(326) |
Mar
(367) |
Apr
(255) |
May
(244) |
Jun
(204) |
Jul
(223) |
Aug
(231) |
Sep
(354) |
Oct
(374) |
Nov
(497) |
Dec
(362) |
| 2008 |
Jan
(322) |
Feb
(482) |
Mar
(658) |
Apr
(422) |
May
(476) |
Jun
(396) |
Jul
(455) |
Aug
(267) |
Sep
(280) |
Oct
(253) |
Nov
(232) |
Dec
(304) |
| 2009 |
Jan
(486) |
Feb
(470) |
Mar
(458) |
Apr
(423) |
May
(696) |
Jun
(461) |
Jul
(551) |
Aug
(575) |
Sep
(134) |
Oct
(110) |
Nov
(157) |
Dec
(102) |
| 2010 |
Jan
(226) |
Feb
(86) |
Mar
(147) |
Apr
(117) |
May
(107) |
Jun
(203) |
Jul
(193) |
Aug
(238) |
Sep
(300) |
Oct
(246) |
Nov
(23) |
Dec
(75) |
| 2011 |
Jan
(133) |
Feb
(195) |
Mar
(315) |
Apr
(200) |
May
(267) |
Jun
(293) |
Jul
(353) |
Aug
(237) |
Sep
(278) |
Oct
(611) |
Nov
(274) |
Dec
(260) |
| 2012 |
Jan
(303) |
Feb
(391) |
Mar
(417) |
Apr
(441) |
May
(488) |
Jun
(655) |
Jul
(590) |
Aug
(610) |
Sep
(526) |
Oct
(478) |
Nov
(359) |
Dec
(372) |
| 2013 |
Jan
(467) |
Feb
(226) |
Mar
(391) |
Apr
(281) |
May
(299) |
Jun
(252) |
Jul
(311) |
Aug
(352) |
Sep
(481) |
Oct
(571) |
Nov
(222) |
Dec
(231) |
| 2014 |
Jan
(185) |
Feb
(329) |
Mar
(245) |
Apr
(238) |
May
(281) |
Jun
(399) |
Jul
(382) |
Aug
(500) |
Sep
(579) |
Oct
(435) |
Nov
(487) |
Dec
(256) |
| 2015 |
Jan
(338) |
Feb
(357) |
Mar
(330) |
Apr
(294) |
May
(191) |
Jun
(108) |
Jul
(142) |
Aug
(261) |
Sep
(190) |
Oct
(54) |
Nov
(83) |
Dec
(22) |
| 2016 |
Jan
(49) |
Feb
(89) |
Mar
(33) |
Apr
(50) |
May
(27) |
Jun
(34) |
Jul
(53) |
Aug
(53) |
Sep
(98) |
Oct
(206) |
Nov
(93) |
Dec
(53) |
| 2017 |
Jan
(65) |
Feb
(82) |
Mar
(102) |
Apr
(86) |
May
(187) |
Jun
(67) |
Jul
(23) |
Aug
(93) |
Sep
(65) |
Oct
(45) |
Nov
(35) |
Dec
(17) |
| 2018 |
Jan
(26) |
Feb
(35) |
Mar
(38) |
Apr
(32) |
May
(8) |
Jun
(43) |
Jul
(27) |
Aug
(30) |
Sep
(43) |
Oct
(42) |
Nov
(38) |
Dec
(67) |
| 2019 |
Jan
(32) |
Feb
(37) |
Mar
(53) |
Apr
(64) |
May
(49) |
Jun
(18) |
Jul
(14) |
Aug
(53) |
Sep
(25) |
Oct
(30) |
Nov
(49) |
Dec
(31) |
| 2020 |
Jan
(87) |
Feb
(45) |
Mar
(37) |
Apr
(51) |
May
(99) |
Jun
(36) |
Jul
(11) |
Aug
(14) |
Sep
(20) |
Oct
(24) |
Nov
(40) |
Dec
(23) |
| 2021 |
Jan
(14) |
Feb
(53) |
Mar
(85) |
Apr
(15) |
May
(19) |
Jun
(3) |
Jul
(14) |
Aug
(1) |
Sep
(57) |
Oct
(73) |
Nov
(56) |
Dec
(22) |
| 2022 |
Jan
(3) |
Feb
(22) |
Mar
(6) |
Apr
(55) |
May
(46) |
Jun
(39) |
Jul
(15) |
Aug
(9) |
Sep
(11) |
Oct
(34) |
Nov
(20) |
Dec
(36) |
| 2023 |
Jan
(79) |
Feb
(41) |
Mar
(99) |
Apr
(169) |
May
(48) |
Jun
(16) |
Jul
(16) |
Aug
(57) |
Sep
(19) |
Oct
|
Nov
|
Dec
|
| S | M | T | W | T | F | S |
|---|---|---|---|---|---|---|
|
|
|
|
|
|
1
(13) |
2
(15) |
|
3
(16) |
4
(42) |
5
(9) |
6
(20) |
7
(22) |
8
(24) |
9
(12) |
|
10
(24) |
11
(11) |
12
(2) |
13
(13) |
14
(8) |
15
|
16
(16) |
|
17
(24) |
18
(36) |
19
(100) |
20
(94) |
21
(50) |
22
(39) |
23
(10) |
|
24
(14) |
25
(19) |
26
(2) |
27
(6) |
28
(17) |
29
(9) |
30
(8) |
|
31
(21) |
|
|
|
|
|
|
|
From: <sv...@va...> - 2009-05-18 04:41:55
|
Author: njn
Date: 2009-05-18 05:41:48 +0100 (Mon, 18 May 2009)
New Revision: 9883
Log:
Merge parts of r9775, r9777, r9789, r9794 from the DARWIN branch.
Modified:
trunk/helgrind/tests/filter_stderr
trunk/memcheck/tests/x86-linux/scalar.c
trunk/memcheck/tests/x86-linux/scalar.stderr.exp
Modified: trunk/helgrind/tests/filter_stderr
===================================================================
--- trunk/helgrind/tests/filter_stderr 2009-05-18 04:25:46 UTC (rev 9882)
+++ trunk/helgrind/tests/filter_stderr 2009-05-18 04:41:48 UTC (rev 9883)
@@ -11,7 +11,7 @@
sed "/^Helgrind, a thread error detector/ , /./ d" |
# Anonymise line numbers in hg_intercepts.c
-sed "s/hg_intercepts.c:[0-9]\+/hg_intercepts.c:.../g" |
+sed "s/hg_intercepts.c:[0-9]*/hg_intercepts.c:.../g" |
# Change (eg) "/lib64/libpthread-2.5.so" into "/...libpthread..."
sed \
@@ -45,8 +45,9 @@
# "Thread #x was created" stack traces are unreliable once you get above
# "pthread_create@* (hg_intercepts.c:...)" -- they can contan
# "pthread_create@GLIBC_", "do_clone", "clone", etc. So we cut all the
-# "at"/"by" lines above "pthread_create@*".
-perl -p -0 -e 's/(Thread #. was created\n)( (at|by)[^\n]*\n)*( by 0x........: pthread_create@\* \(hg_intercepts.c:...\)\n)/$1 ...\n$4/gs' |
+# "at"/"by" lines above "pthread_create@*". We also convert
+# "pthread_create" into "pthread_create@*".
+perl -p -0 -e 's/(Thread #. was created\n)( (at|by)[^\n]*\n)*( by 0x........: pthread_create)(@\*)?( \(hg_intercepts.c:...\)\n)/$1 ...\n$4@*$6/gs' |
# Anything below "mythread_wrapper" in stack traces is unreliable,
# containing libc and libpthread stuff like start_thread, clone, etc. So we
Modified: trunk/memcheck/tests/x86-linux/scalar.c
===================================================================
--- trunk/memcheck/tests/x86-linux/scalar.c 2009-05-18 04:25:46 UTC (rev 9882)
+++ trunk/memcheck/tests/x86-linux/scalar.c 2009-05-18 04:41:48 UTC (rev 9883)
@@ -17,6 +17,10 @@
// when memory is unaddressable, and so tries to dereference it when doing
// PRE_MEM_READ/PRE_MEM_WRITE calls. (Note that Memcheck will
// always issue an error message immediately before these seg faults occur).
+//
+// The output has numbers like "3s 2m" for each syscall. "s" is short for
+// "scalar", ie. the argument itself is undefined. "m" is short for "memory",
+// ie. the argument points to memory which is unaddressable.
int main(void)
{
Modified: trunk/memcheck/tests/x86-linux/scalar.stderr.exp
===================================================================
--- trunk/memcheck/tests/x86-linux/scalar.stderr.exp 2009-05-18 04:25:46 UTC (rev 9882)
+++ trunk/memcheck/tests/x86-linux/scalar.stderr.exp 2009-05-18 04:41:48 UTC (rev 9883)
@@ -582,25 +582,25 @@
...
Address 0x........ is 0 bytes after a block of size 4 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (scalar.c:24)
+ by 0x........: main (scalar.c:28)
Syscall param sigaction(act->sa_mask) points to unaddressable byte(s)
...
Address 0x........ is 4 bytes after a block of size 4 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (scalar.c:24)
+ by 0x........: main (scalar.c:28)
Syscall param sigaction(act->sa_flags) points to unaddressable byte(s)
...
Address 0x........ is 8 bytes after a block of size 4 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (scalar.c:24)
+ by 0x........: main (scalar.c:28)
Syscall param sigaction(oldact) points to unaddressable byte(s)
...
Address 0x........ is 0 bytes after a block of size 4 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (scalar.c:24)
+ by 0x........: main (scalar.c:28)
-----------------------------------------------------
68: __NR_sgetmask n/a
-----------------------------------------------------
@@ -1212,13 +1212,13 @@
...
Address 0x........ is 0 bytes after a block of size 4 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (scalar.c:24)
+ by 0x........: main (scalar.c:28)
Syscall param sigprocmask(oldset) points to unaddressable byte(s)
...
Address 0x........ is 0 bytes after a block of size 4 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (scalar.c:24)
+ by 0x........: main (scalar.c:28)
-----------------------------------------------------
127: __NR_create_module ni
-----------------------------------------------------
@@ -1731,7 +1731,7 @@
...
Address 0x........ is 4 bytes after a block of size 4 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (scalar.c:24)
+ by 0x........: main (scalar.c:28)
Syscall param rt_sigaction(act->sa_mask) points to unaddressable byte(s)
...
@@ -1741,13 +1741,13 @@
...
Address 0x........ is 8 bytes after a block of size 4 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (scalar.c:24)
+ by 0x........: main (scalar.c:28)
Syscall param rt_sigaction(oldact) points to unaddressable byte(s)
...
Address 0x........ is 4 bytes after a block of size 4 alloc'd
at 0x........: malloc (vg_replace_malloc.c:...)
- by 0x........: main (scalar.c:24)
+ by 0x........: main (scalar.c:28)
-----------------------------------------------------
175: __NR_rt_sigprocmask 4s 2m
-----------------------------------------------------
|
|
From: <sv...@va...> - 2009-05-18 04:25:55
|
Author: njn Date: 2009-05-18 05:25:46 +0100 (Mon, 18 May 2009) New Revision: 9882 Log: Add some missing files. Modified: branches/DARWIN/docs/internals/Makefile.am Modified: branches/DARWIN/docs/internals/Makefile.am =================================================================== --- branches/DARWIN/docs/internals/Makefile.am 2009-05-18 04:24:22 UTC (rev 9881) +++ branches/DARWIN/docs/internals/Makefile.am 2009-05-18 04:25:46 UTC (rev 9882) @@ -5,6 +5,8 @@ BIG_APP_NOTES.txt \ Darwin-notes.txt \ debugstub_removed_at_r9477.diff \ + debugstub_removed_at_r9711.diff \ + debugstub_removed_at_r9759.diff \ directory-structure.txt \ howto_BUILD_KDE42.txt \ howto_oprofile.txt \ |
|
From: <sv...@va...> - 2009-05-18 04:24:29
|
Author: njn Date: 2009-05-18 05:24:22 +0100 (Mon, 18 May 2009) New Revision: 9881 Log: This should have gone in with r9880. Modified: branches/DARWIN/docs/internals/Makefile.am Modified: branches/DARWIN/docs/internals/Makefile.am =================================================================== --- branches/DARWIN/docs/internals/Makefile.am 2009-05-18 04:23:41 UTC (rev 9880) +++ branches/DARWIN/docs/internals/Makefile.am 2009-05-18 04:24:22 UTC (rev 9881) @@ -1,6 +1,7 @@ EXTRA_DIST = \ 3_0_BUGSTATUS.txt 3_1_BUGSTATUS.txt \ 3_2_BUGSTATUS.txt 3_3_BUGSTATUS.txt \ + 3_4_BUGSTATUS.txt \ BIG_APP_NOTES.txt \ Darwin-notes.txt \ debugstub_removed_at_r9477.diff \ |
|
From: <sv...@va...> - 2009-05-18 04:23:47
|
Author: njn
Date: 2009-05-18 05:23:41 +0100 (Mon, 18 May 2009)
New Revision: 9880
Log:
Add 3_4_BUGSTATUS to DARWIN branch to minimise difference with the trunk.
Added:
branches/DARWIN/docs/internals/3_4_BUGSTATUS.txt
Added: branches/DARWIN/docs/internals/3_4_BUGSTATUS.txt
===================================================================
--- branches/DARWIN/docs/internals/3_4_BUGSTATUS.txt (rev 0)
+++ branches/DARWIN/docs/internals/3_4_BUGSTATUS.txt 2009-05-18 04:23:41 UTC (rev 9880)
@@ -0,0 +1,130 @@
+
+Bugs reported after the release of 3.4.1. Not sure what happened to
+any record of bugs reported after the release of 3.4.0. Oh well.
+
+For ref:
+
+(3.4.1.RC1: 24 Feb 2009, vex r1884, valgrind r9253).
+(3.4.1: 28 Feb 2009, vex r1884, valgrind r9293).
+
+-------------------
+
+185128 Helgrind: hg_main.c:3860 (hg_handle_client_request):
+ Assertion 'found' failed.
+
+185499 testcase usability kde brainfuck
+
+185517 Wrong write detection
+
+185794 "WARNING: unhandled syscall: 285" (fallocate) on x86_64
+ in several tools
+
+185801 exp-ptrcheck: evaluate_Dwarf3_Expr: unhandled DW_OP_ 0x93
+
+185816 Valgrind is unable to handle debug info for files with
+ split debug info that are prelinked afterwards
+
+186238 bbToIR_AMD64: disInstr miscalculated next %rip
+
+186248 Support full AMD floating-point implementation.
+
+186507 exp-ptrcheck unhandled syscalls prctl, etc.
+
+186790 Suppression pattern used for leaks are not reported
+
+186796 Symbols with length>200 in suppression files are ignored
+
+157154 documentation (leak-resolution doc speaks about num-callers
+ def=4) + what is a loss record
+
+186963 Report mutexes humanic names
+
+187043 sched_getcpu() produces Segmentation Fault
+
+187048 mutex PTHREAD_PROCESS_SHARED attribute missinterpretation
+
+187416 support for __NR_{setregid,setreuid,setresuid} in
+ exp-ptrcheck
+
+187680 valgrind: the 'impossible' happened (probably invalid)
+
+187760 valgrind: the 'impossible' happened: VG_(arena_memalign)
+
+188038 Helgrind internal error
+
+188046 bashisms in the configure script
+
+188127 vex amd64->IR: unhandled instruction bytes: 0xF0 0xF 0xB0 0xA
+ (ancient cmpxchg stuff, probably invalid now)
+
+188161 valgrind --track-origins=yes asserts (transient trunk
+ stuff, now fixed?)
+
+188248 pthread_cleanup_push, pthread_rwlock_unlock, assertion
+ fail "!lock->heldBy"
+
+188258 javascript fragment gives different result under valgrind
+ (requires SSSE3 exns; cant easily fix?)
+
+188427 Add support for epoll_create1 (with patch)
+
+188530 Support for SIOCGSTAMPNS
+
+188560 Include valgrind.spec in the tarball
+
+188572 Valgrind on Mac should suppress setenv() mem leak
+
+188656 valgrind doesn't build on x86_64 machine (INVALID)
+
+188657 Massif: ms_main.c:1700 (update_stack_stats): Assertion
+ 'stacks_szB >= -stack_szB_delta' failed
+
+188735 Cachegrind fails to produce any output on java apps
+
+188969 thread's stack is not computed correctly
+
+188984 Data corruption for returned from function long double
+ (fp grumblings)
+
+189028 impossible happend in unlinkBlock (m_mallocfree.c:206)
+ (usual memory corruption) -- invalid
+
+189054 Valgrind fails to build because of duplicate non-local
+ asm labels
+
+189143 crash when running using wine to run vcsetup.exe under
+ valgrind
+
+189183 valgrind core dump on aix5.3 platform
+
+189232 Illegal opcode - unhandled instruction bytes: 0xCB 0x55
+ 0x8B 0xEC
+
+189361 Cache simulation slightly wrong
+
+189661 Valgrind on Mac hangs on a race-condition
+
+189737 vex amd64->IR: unhandled instruction bytes: 0xAC (lods)
+
+189762 epoll_create syscall not handled (in ptrcheck)
+
+189763 drd assertion failure: s_threadinfo[tid].is_recording
+
+190219 unhandled syscall: 328 (x86-linux, __NR_eventfd2 ?)
+
+190390 Allow to set the number of frames for helgrind conflicts
+
+190391 okular crashes helgrind
+ ==181394
+
+190429 Valgrind reports lost of errors in ld.so with x86_64
+ 2.9.90 glibc
+
+(next 2 are wine-specific)
+190660 False warnings for _strlen
+190675 Spurious error "Wrong time stamp of .PDB file"
+
+190820 No debug information on powerpc-linux
+
+(-- 27 Apr 09 --)
+
|
|
From: <sv...@va...> - 2009-05-18 04:21:28
|
Author: njn
Date: 2009-05-18 05:21:19 +0100 (Mon, 18 May 2009)
New Revision: 9879
Log:
Merged r9087, part of r9091, r9155 (DRD suppression changes) from the trunk.
Modified:
branches/DARWIN/glibc-2.X-drd.supp
Modified: branches/DARWIN/glibc-2.X-drd.supp
===================================================================
--- branches/DARWIN/glibc-2.X-drd.supp 2009-05-18 02:44:59 UTC (rev 9878)
+++ branches/DARWIN/glibc-2.X-drd.supp 2009-05-18 04:21:19 UTC (rev 9879)
@@ -21,7 +21,6 @@
drd:ConflictingAccess
obj:/lib*/ld-*.so
obj:/lib*/ld-*.so
- obj:/lib*/ld-*.so
}
{
dl-dlsym-1
@@ -48,6 +47,11 @@
fun:backtrace_symbols
}
{
+ libc-stdio
+ drd:ConflictingAccess
+ obj:/lib*/libc-*
+}
+{
libc
drd:ConflictingAccess
fun:__libc_enable_asynccancel
@@ -312,6 +316,13 @@
fun:g_slice_free_chain_with_offset
}
{
+ libQtCore-deref-that-calls-QThreadData-destructor
+ drd:ConflictingAccess
+ fun:_ZN11QThreadDataD1Ev
+ fun:_ZN11QThreadData5derefEv
+ obj:/usr/lib*/libQtCore.so.4.*
+}
+{
libQtCore-4.0/4.1-Q_GLOBAL_STATIC-connectionList
drd:ConflictingAccess
obj:/usr/lib*/libQtCore.so.4.*
|
|
From: <sv...@va...> - 2009-05-18 02:45:18
|
Author: njn
Date: 2009-05-18 03:44:59 +0100 (Mon, 18 May 2009)
New Revision: 9878
Log:
Merged r9851, r9852 (DRD tweaks) from the trunk.
Added:
branches/DARWIN/drd/tests/pth_mutex_reinit.c
branches/DARWIN/drd/tests/pth_mutex_reinit.stderr.exp
branches/DARWIN/drd/tests/pth_mutex_reinit.vgtest
Modified:
branches/DARWIN/drd/drd_mutex.c
branches/DARWIN/drd/tests/
branches/DARWIN/drd/tests/Makefile.am
Modified: branches/DARWIN/drd/drd_mutex.c
===================================================================
--- branches/DARWIN/drd/drd_mutex.c 2009-05-18 02:27:01 UTC (rev 9877)
+++ branches/DARWIN/drd/drd_mutex.c 2009-05-18 02:44:59 UTC (rev 9878)
@@ -193,6 +193,7 @@
VG_(get_IP)(vg_tid),
"Mutex reinitialization",
&MEI);
+ p->mutex_type = mutex_type;
return p;
}
p = DRD_(mutex_get_or_allocate)(mutex, mutex_type);
Property changes on: branches/DARWIN/drd/tests
___________________________________________________________________
Name: svn:ignore
- *.stderr.diff*
*.stderr.out
*.stdout.diff*
*.stdout.out
.deps
atomic_var
bar_bad
bar_trivial
boost_thread
circular_buffer
drd_bitmap_test
fp_race
hg01_all_ok
hg02_deadlock
hg03_inherit
hg04_race
hg05_race2
hg06_readshared
hold_lock
linuxthreads_det
Makefile
Makefile.in
matinv
memory_allocation
monitor_example
new_delete
omp_matinv
omp_prime
omp_printf
pth_barrier
pth_barrier_race
pth_barrier_reinit
pth_broadcast
pth_cancel_locked
pth_cond_race
pth_create_chain
pth_create_glibc_2_0
pth_detached
pth_detached_sem
pth_inconsistent_cond_wait
pth_process_shared_mutex
pth_spinlock
qt4_mutex
qt4_rwlock
qt4_semaphore
recursive_mutex
rwlock_race
rwlock_test
sem_as_mutex
sigalrm
tc01_simple_race
tc02_simple_tls
tc03_re_excl
tc04_free_lock
tc05_simple_race
tc06_two_races
tc07_hbl1
tc08_hbl2
tc09_bad_unlock
tc10_rec_lock
tc11_XCHG
tc12_rwl_trivial
tc13_laog1
tc15_laog_lockdel
tc16_byterace
tc17_sembar
tc18_semabuse
tc19_shadowmem
tc20_verifywrap
tc21_pthonce
tc22_exit_w_lock
tc23_bogus_condwait
tc24_nonzero_sem
trylock
vg_regtest.tmp*
+ *.stderr.diff*
*.stderr.out
*.stdout.diff*
*.stdout.out
.deps
atomic_var
bar_bad
bar_trivial
boost_thread
circular_buffer
drd_bitmap_test
fp_race
hg01_all_ok
hg02_deadlock
hg03_inherit
hg04_race
hg05_race2
hg06_readshared
hold_lock
linuxthreads_det
Makefile
Makefile.in
matinv
memory_allocation
monitor_example
new_delete
omp_matinv
omp_prime
omp_printf
pth_barrier
pth_barrier_race
pth_barrier_reinit
pth_broadcast
pth_cancel_locked
pth_cond_race
pth_create_chain
pth_create_glibc_2_0
pth_detached
pth_detached_sem
pth_inconsistent_cond_wait
pth_mutex_reinit
pth_process_shared_mutex
pth_spinlock
qt4_mutex
qt4_rwlock
qt4_semaphore
recursive_mutex
rwlock_race
rwlock_test
sem_as_mutex
sigalrm
tc01_simple_race
tc02_simple_tls
tc03_re_excl
tc04_free_lock
tc05_simple_race
tc06_two_races
tc07_hbl1
tc08_hbl2
tc09_bad_unlock
tc10_rec_lock
tc11_XCHG
tc12_rwl_trivial
tc13_laog1
tc15_laog_lockdel
tc16_byterace
tc17_sembar
tc18_semabuse
tc19_shadowmem
tc20_verifywrap
tc21_pthonce
tc22_exit_w_lock
tc23_bogus_condwait
tc24_nonzero_sem
trylock
vg_regtest.tmp*
Modified: branches/DARWIN/drd/tests/Makefile.am
===================================================================
--- branches/DARWIN/drd/tests/Makefile.am 2009-05-18 02:27:01 UTC (rev 9877)
+++ branches/DARWIN/drd/tests/Makefile.am 2009-05-18 02:44:59 UTC (rev 9878)
@@ -19,16 +19,16 @@
atomic_var.vgtest \
bar_bad.stderr.exp \
bar_bad.vgtest \
+ bar_trivial.stderr.exp \
bar_trivial.stdout.exp \
- bar_trivial.stderr.exp \
bar_trivial.vgtest \
boost_thread.stderr.exp \
boost_thread.vgtest \
circular_buffer.stderr.exp-with-atomic-builtins \
circular_buffer.stderr.exp-without-atomic-builtins \
circular_buffer.vgtest \
+ custom_alloc.stderr.exp \
custom_alloc.vgtest \
- custom_alloc.stderr.exp \
drd_bitmap_test.stderr.exp \
drd_bitmap_test.stdout.exp \
drd_bitmap_test.vgtest \
@@ -114,8 +114,10 @@
pth_inconsistent_cond_wait.stderr.exp1 \
pth_inconsistent_cond_wait.stderr.exp2 \
pth_inconsistent_cond_wait.vgtest \
+ pth_mutex_reinit.stderr.exp \
+ pth_mutex_reinit.vgtest \
+ pth_process_shared_mutex.c \
pth_process_shared_mutex.vgtest \
- pth_process_shared_mutex.c \
pth_spinlock.stderr.exp \
pth_spinlock.vgtest \
qt4_mutex.stderr.exp \
@@ -220,8 +222,9 @@
pth_create_chain \
pth_detached \
pth_detached_sem \
+ pth_inconsistent_cond_wait \
+ pth_mutex_reinit \
pth_process_shared_mutex \
- pth_inconsistent_cond_wait \
recursive_mutex \
rwlock_race \
rwlock_test \
Copied: branches/DARWIN/drd/tests/pth_mutex_reinit.c (from rev 9852, trunk/drd/tests/pth_mutex_reinit.c)
===================================================================
--- branches/DARWIN/drd/tests/pth_mutex_reinit.c (rev 0)
+++ branches/DARWIN/drd/tests/pth_mutex_reinit.c 2009-05-18 02:44:59 UTC (rev 9878)
@@ -0,0 +1,36 @@
+/* Test program that triggers mutex reinitialization. */
+
+
+#define _GNU_SOURCE
+
+#include <assert.h>
+#include <pthread.h>
+#include <stdio.h>
+#include <stdlib.h>
+
+
+int main(int argc, char** argv)
+{
+ pthread_mutex_t m;
+ pthread_mutexattr_t attr;
+
+ pthread_mutexattr_init(&attr);
+ pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_NORMAL);
+ pthread_mutex_init(&m, &attr);
+ pthread_mutexattr_destroy(&attr);
+ pthread_mutex_lock(&m);
+ pthread_mutex_unlock(&m);
+
+ pthread_mutexattr_init(&attr);
+ pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
+ pthread_mutex_init(&m, &attr);
+ pthread_mutexattr_destroy(&attr);
+ pthread_mutex_lock(&m);
+ pthread_mutex_unlock(&m);
+
+ pthread_mutex_destroy(&m);
+
+ fprintf(stderr, "Done.\n");
+
+ return 0;
+}
Copied: branches/DARWIN/drd/tests/pth_mutex_reinit.stderr.exp (from rev 9852, trunk/drd/tests/pth_mutex_reinit.stderr.exp)
===================================================================
--- branches/DARWIN/drd/tests/pth_mutex_reinit.stderr.exp (rev 0)
+++ branches/DARWIN/drd/tests/pth_mutex_reinit.stderr.exp 2009-05-18 02:44:59 UTC (rev 9878)
@@ -0,0 +1,10 @@
+
+Mutex reinitialization: mutex 0x........, recursion count 0, owner 1.
+ at 0x........: pthread_mutex_init (drd_pthread_intercepts.c:?)
+ by 0x........: main (pth_mutex_reinit.c:?)
+mutex 0x........ was first observed at:
+ at 0x........: pthread_mutex_init (drd_pthread_intercepts.c:?)
+ by 0x........: main (pth_mutex_reinit.c:?)
+Done.
+
+ERROR SUMMARY: 1 errors from 1 contexts (suppressed: 0 from 0)
Copied: branches/DARWIN/drd/tests/pth_mutex_reinit.vgtest (from rev 9852, trunk/drd/tests/pth_mutex_reinit.vgtest)
===================================================================
--- branches/DARWIN/drd/tests/pth_mutex_reinit.vgtest (rev 0)
+++ branches/DARWIN/drd/tests/pth_mutex_reinit.vgtest 2009-05-18 02:44:59 UTC (rev 9878)
@@ -0,0 +1,3 @@
+prereq: test -e pth_mutex_reinit && ./supported_libpthread
+vgopts: --var-info=yes --check-stack-var=yes
+prog: pth_mutex_reinit
|
|
From: Tom H. <th...@cy...> - 2009-05-18 02:44:18
|
Nightly build on lloyd ( x86_64, Fedora 7 ) started at 2009-05-18 03:05:06 BST Results unchanged from 24 hours ago Checking out valgrind source tree ... done Configuring valgrind ... done Building valgrind ... done Running regression tests ... done Regression test results follow == 481 tests, 0 stderr failures, 0 stdout failures, 0 post failures == |
|
From: Tom H. <th...@cy...> - 2009-05-18 02:27:50
|
Nightly build on mg ( x86_64, Fedora 9 ) started at 2009-05-18 03:10:05 BST Results unchanged from 24 hours ago Checking out valgrind source tree ... done Configuring valgrind ... done Building valgrind ... done Running regression tests ... failed Regression test results follow == 487 tests, 0 stderr failures, 1 stdout failure, 0 post failures == none/tests/linux/mremap2 (stdout) |
|
From: <sv...@va...> - 2009-05-18 02:27:17
|
Author: njn
Date: 2009-05-18 03:27:01 +0100 (Mon, 18 May 2009)
New Revision: 9877
Log:
Some minor changes to sync with the changes that occurred in the trunk for
r9876.
Modified:
branches/DARWIN/coregrind/m_aspacemgr/aspacemgr-common.c
branches/DARWIN/coregrind/m_libcfile.c
branches/DARWIN/coregrind/m_libcproc.c
branches/DARWIN/coregrind/m_libcsignal.c
branches/DARWIN/coregrind/m_scheduler/scheduler.c
branches/DARWIN/coregrind/m_signals.c
branches/DARWIN/coregrind/m_syscall.c
branches/DARWIN/coregrind/m_syswrap/syswrap-generic.c
branches/DARWIN/coregrind/m_syswrap/syswrap-main.c
Modified: branches/DARWIN/coregrind/m_aspacemgr/aspacemgr-common.c
===================================================================
--- branches/DARWIN/coregrind/m_aspacemgr/aspacemgr-common.c 2009-05-18 02:12:08 UTC (rev 9876)
+++ branches/DARWIN/coregrind/m_aspacemgr/aspacemgr-common.c 2009-05-18 02:27:01 UTC (rev 9877)
@@ -272,10 +272,12 @@
Int ML_(am_fcntl) ( Int fd, Int cmd, Addr arg )
{
-# if defined(VGO_darwin)
+# if defined(VGO_linux) || defined(VGO_aix5)
+ SysRes res = VG_(do_syscall3)(__NR_fcntl, fd, cmd, arg);
+# elif defined(VGO_darwin)
SysRes res = VG_(do_syscall3)(__NR_fcntl_nocancel, fd, cmd, arg);
# else
- SysRes res = VG_(do_syscall3)(__NR_fcntl, fd, cmd, arg);
+# error "Unknown OS"
# endif
return sr_isError(res) ? -1 : sr_Res(res);
}
Modified: branches/DARWIN/coregrind/m_libcfile.c
===================================================================
--- branches/DARWIN/coregrind/m_libcfile.c 2009-05-18 02:12:08 UTC (rev 9876)
+++ branches/DARWIN/coregrind/m_libcfile.c 2009-05-18 02:27:01 UTC (rev 9877)
@@ -188,8 +188,6 @@
OffT VG_(lseek) ( Int fd, OffT offset, Int whence )
{
# if defined(VGP_x86_darwin)
- /* ppc32_darwin is like this, except the two offset args are
- the other way round, unsurprisingly */
SysRes res = VG_(do_syscall4)(__NR_lseek, fd,
offset & 0xffffffff, offset >> 32, whence);
# elif defined(VGP_amd64_darwin) \
@@ -213,7 +211,7 @@
/* Note that on Darwin, the _p_vkistat fields st_{a,m,c}time{_,nsec}
"happen" to have the same name as on Linux only due to a bit of
#define magic in vki-darwin.h. */
-# define TRANSLATE_TO_vg_stat(_p_vgstat, _p_vkistat) \
+#define TRANSLATE_TO_vg_stat(_p_vgstat, _p_vkistat) \
do { \
(_p_vgstat)->dev = (ULong)( (_p_vkistat)->st_dev ); \
(_p_vgstat)->ino = (ULong)( (_p_vkistat)->st_ino ); \
@@ -569,7 +567,14 @@
SysRes VG_(pread) ( Int fd, void* buf, Int count, OffT offset )
{
SysRes res;
-# if defined(VGP_amd64_darwin)
+# if defined(VGO_linux) || defined(VGO_aix5)
+ /* Linux, AIX5 */
+ OffT off = VG_(lseek)( fd, offset, VKI_SEEK_SET);
+ if (off < 0)
+ return VG_(mk_SysRes_Error)( VKI_EINVAL );
+ res = VG_(do_syscall3)(__NR_read, fd, (UWord)buf, count );
+ return res;
+# elif defined(VGP_amd64_darwin)
res = VG_(do_syscall4)(__NR_pread_nocancel, fd, (UWord)buf, count, offset);
return res;
# elif defined(VGP_x86_darwin)
@@ -577,13 +582,6 @@
res = VG_(do_syscall5)(__NR_pread_nocancel, fd, (UWord)buf, count,
offset & 0xffffffff, offset >> 32);
return res;
-# elif defined(VGO_linux) || defined(VGO_aix5)
- /* Linux, AIX5 */
- OffT off = VG_(lseek)( fd, offset, VKI_SEEK_SET);
- if (off < 0)
- return VG_(mk_SysRes_Error)( VKI_EINVAL );
- res = VG_(do_syscall3)(__NR_read, fd, (UWord)buf, count );
- return res;
# else
# error "Unknown platform"
# endif
Modified: branches/DARWIN/coregrind/m_libcproc.c
===================================================================
--- branches/DARWIN/coregrind/m_libcproc.c 2009-05-18 02:12:08 UTC (rev 9876)
+++ branches/DARWIN/coregrind/m_libcproc.c 2009-05-18 02:27:01 UTC (rev 9877)
@@ -405,20 +405,7 @@
Int VG_(gettid)(void)
{
-# if defined(VGO_aix5)
- SysRes res;
- Int r;
- vg_assert(__NR_AIX5__thread_self != __NR_AIX5_UNKNOWN);
- res = VG_(do_syscall0)(__NR_AIX5__thread_self);
- r = sr_Res(res);
- return r;
-
-# elif defined(VGO_darwin)
- // Darwin's gettid syscall is something else.
- // Use Mach thread ports for lwpid instead.
- return mach_thread_self();
-
-# elif defined(VGO_linux)
+# if defined(VGO_linux)
SysRes res = VG_(do_syscall0)(__NR_gettid);
if (sr_isError(res) && sr_Res(res) == VKI_ENOSYS) {
@@ -452,6 +439,19 @@
return sr_Res(res);
+# elif defined(VGO_aix5)
+ SysRes res;
+ Int r;
+ vg_assert(__NR_AIX5__thread_self != __NR_AIX5_UNKNOWN);
+ res = VG_(do_syscall0)(__NR_AIX5__thread_self);
+ r = sr_Res(res);
+ return r;
+
+# elif defined(VGO_darwin)
+ // Darwin's gettid syscall is something else.
+ // Use Mach thread ports for lwpid instead.
+ return mach_thread_self();
+
# else
# error "Unknown OS"
# endif
@@ -591,7 +591,22 @@
static ULong base = 0;
ULong now;
-# if defined(VGO_aix5)
+# if defined(VGO_linux)
+ { SysRes res;
+ struct vki_timespec ts_now;
+ res = VG_(do_syscall2)(__NR_clock_gettime, VKI_CLOCK_MONOTONIC,
+ (UWord)&ts_now);
+ if (sr_isError(res) == 0) {
+ now = ts_now.tv_sec * 1000000ULL + ts_now.tv_nsec / 1000;
+ } else {
+ struct vki_timeval tv_now;
+ res = VG_(do_syscall2)(__NR_gettimeofday, (UWord)&tv_now, (UWord)NULL);
+ vg_assert(! sr_isError(res));
+ now = tv_now.tv_sec * 1000000ULL + tv_now.tv_usec;
+ }
+ }
+
+# elif defined(VGO_aix5)
/* AIX requires a totally different implementation since
sys_gettimeofday doesn't exist. We use the POWER real-time
register facility. This will SIGILL on PowerPC 970 on AIX,
@@ -610,21 +625,6 @@
now = ((ULong)sec1) * 1000000ULL;
now += (ULong)(nsec / 1000);
-# elif defined(VGO_linux)
- { SysRes res;
- struct vki_timespec ts_now;
- res = VG_(do_syscall2)(__NR_clock_gettime, VKI_CLOCK_MONOTONIC,
- (UWord)&ts_now);
- if (sr_isError(res) == 0) {
- now = ts_now.tv_sec * 1000000ULL + ts_now.tv_nsec / 1000;
- } else {
- struct vki_timeval tv_now;
- res = VG_(do_syscall2)(__NR_gettimeofday, (UWord)&tv_now, (UWord)NULL);
- vg_assert(! sr_isError(res));
- now = tv_now.tv_sec * 1000000ULL + tv_now.tv_usec;
- }
- }
-
# elif defined(VGO_darwin)
{ SysRes res;
struct vki_timeval tv_now;
Modified: branches/DARWIN/coregrind/m_libcsignal.c
===================================================================
--- branches/DARWIN/coregrind/m_libcsignal.c 2009-05-18 02:12:08 UTC (rev 9876)
+++ branches/DARWIN/coregrind/m_libcsignal.c 2009-05-18 02:27:01 UTC (rev 9877)
@@ -221,7 +221,15 @@
const vki_sigaction_toK_t* act,
vki_sigaction_fromK_t* oldact)
{
-# if defined(VGO_darwin)
+# if defined(VGO_linux) || defined(VGO_aix5)
+ /* Normal case: vki_sigaction_toK_t and vki_sigaction_fromK_t are
+ identical types. */
+ SysRes res = VG_(do_syscall4)(__NR_rt_sigaction,
+ signum, (UWord)act, (UWord)oldact,
+ _VKI_NSIG_WORDS * sizeof(UWord));
+ return sr_isError(res) ? -1 : 0;
+
+# elif defined(VGO_darwin)
/* If we're passing a new action to the kernel, make a copy of the
new action, install our own sa_tramp field in it, and ignore
whatever we were provided with. This is OK because all the
@@ -266,13 +274,6 @@
}
return sr_isError(res) ? -1 : 0;
-# elif defined(VGO_linux) || defined(VGO_aix5)
- /* Normal case: vki_sigaction_toK_t and vki_sigaction_fromK_t are
- identical types. */
- SysRes res = VG_(do_syscall4)(__NR_rt_sigaction,
- signum, (UWord)act, (UWord)oldact,
- _VKI_NSIG_WORDS * sizeof(UWord));
- return sr_isError(res) ? -1 : 0;
# else
# error "Unsupported OS"
# endif
Modified: branches/DARWIN/coregrind/m_scheduler/scheduler.c
===================================================================
--- branches/DARWIN/coregrind/m_scheduler/scheduler.c 2009-05-18 02:12:08 UTC (rev 9876)
+++ branches/DARWIN/coregrind/m_scheduler/scheduler.c 2009-05-18 02:27:01 UTC (rev 9877)
@@ -1213,14 +1213,14 @@
vex does not know what it should be. Vex sets the next
address to zero, so if you don't set guest_EIP, the thread
will jump to zero afterwards and probably die as a result. */
-# if defined(VGP_x86_darwin)
+# if defined(VGP_x86_linux)
+ vg_assert2(0, "VG_(scheduler), phase 3: "
+ "sysenter_x86 on x86-linux is not supported");
+# elif defined(VGP_x86_darwin)
/* return address in client edx */
VG_(threads)[tid].arch.vex.guest_EIP
= VG_(threads)[tid].arch.vex.guest_EDX;
handle_syscall(tid, trc);
-# elif defined(VGP_x86_linux)
- vg_assert2(0, "VG_(scheduler), phase 3: "
- "sysenter_x86 on x86-linux is not supported");
# else
vg_assert2(0, "VG_(scheduler), phase 3: "
"sysenter_x86 on non-x86 platform?!?!");
Modified: branches/DARWIN/coregrind/m_signals.c
===================================================================
--- branches/DARWIN/coregrind/m_syscall.c 2009-05-18 02:12:08 UTC (rev 9876)
+++ branches/DARWIN/coregrind/m_syscall.c 2009-05-18 02:27:01 UTC (rev 9877)
@@ -40,7 +40,7 @@
#if defined(VGO_linux)
-/* Make a SysRes value from an syscall return value. This is
+/* Make a SysRes value from a syscall return value. This is
Linux-specific.
From:
Modified: branches/DARWIN/coregrind/m_syswrap/syswrap-generic.c
===================================================================
--- branches/DARWIN/coregrind/m_syswrap/syswrap-generic.c 2009-05-18 02:12:08 UTC (rev 9876)
+++ branches/DARWIN/coregrind/m_syswrap/syswrap-generic.c 2009-05-18 02:27:01 UTC (rev 9877)
@@ -2462,12 +2462,7 @@
while (!i_am_the_only_thread()) {
/* Let other thread(s) run */
VG_(vg_yield)();
-#if defined(VGO_darwin)
- I_die_here;
- // DDD: #warning GrP fixme signals
-#else
VG_(poll_signals)(self);
-#endif
}
vg_assert(i_am_the_only_thread());
}
Modified: branches/DARWIN/coregrind/m_syswrap/syswrap-main.c
===================================================================
--- branches/DARWIN/coregrind/m_syswrap/syswrap-main.c 2009-05-18 02:12:08 UTC (rev 9876)
+++ branches/DARWIN/coregrind/m_syswrap/syswrap-main.c 2009-05-18 02:27:01 UTC (rev 9877)
@@ -72,12 +72,6 @@
ppc64 r2 r3 r4 r5 r6 r7 r8 r9 r10 r3(res),r4(err)
DARWIN:
- ppc32 r0 r3 r4 r5 r6 r7 r8 r9 r10 r3+r4+pc
- BSD syscalls: result is in r4:r3, (hiW:loW)
- on failure, execution returns to the instruction following 'sc'
- on success, execution returns to the 2nd instruction following 'sc'
- Mach traps: result is in r3, and there is no error flag.
- ppc64 r0 r3 r4 r5 r6 r7 r8 ?? ?? r3+CR0.SO (== ARG1)
x86 eax +4 +8 +12 +16 +20 +24 +28 +32 edx:eax, eflags.c
amd64 rax rdi rsi rdx rcx r8 r9 +8 +16 rdx:rax, rflags.c
@@ -162,8 +156,6 @@
Fail(N) ==> r3 = N, CR0.SO = 1
Darwin:
- ppc32: Success(N) ==> r3 = N, pc = LAST_SC+8
- Fail(N) ==> r3 = N, pc = LAST_SC+4
x86: Success(N) ==> edx:eax = N, cc = 0
Fail(N) ==> edx:eax = N, cc = 1
|
|
From: <sv...@va...> - 2009-05-18 02:12:24
|
Author: njn Date: 2009-05-18 03:12:08 +0100 (Mon, 18 May 2009) New Revision: 9876 Log: Merged non-Darwin-specific parts of r9397,r9423,r9490, 9461, 9462 from the DARWIN branch. A big ugly DARWIN/trunk sync commit, mostly to do with changing the representation of SysRes and vki_sigset_t. Functionality of the trunk shouldn't be changed by it. Modified: trunk/cachegrind/cg_main.c trunk/callgrind/command.c trunk/callgrind/dump.c trunk/coregrind/m_aspacemgr/aspacemgr-common.c trunk/coregrind/m_aspacemgr/aspacemgr-linux.c trunk/coregrind/m_commandline.c trunk/coregrind/m_coredump/coredump-elf.c trunk/coregrind/m_debuginfo/debuginfo.c trunk/coregrind/m_debuginfo/readelf.c trunk/coregrind/m_errormgr.c trunk/coregrind/m_initimg/initimg-linux.c trunk/coregrind/m_libcfile.c trunk/coregrind/m_libcproc.c trunk/coregrind/m_libcsignal.c trunk/coregrind/m_machine.c trunk/coregrind/m_main.c trunk/coregrind/m_mallocfree.c trunk/coregrind/m_scheduler/scheduler.c trunk/coregrind/m_signals.c trunk/coregrind/m_syscall.c trunk/coregrind/m_syswrap/priv_types_n_macros.h trunk/coregrind/m_syswrap/syscall-amd64-linux.S trunk/coregrind/m_syswrap/syscall-ppc32-aix5.S trunk/coregrind/m_syswrap/syscall-ppc32-linux.S trunk/coregrind/m_syswrap/syscall-ppc64-aix5.S trunk/coregrind/m_syswrap/syscall-ppc64-linux.S trunk/coregrind/m_syswrap/syscall-x86-linux.S trunk/coregrind/m_syswrap/syswrap-amd64-linux.c trunk/coregrind/m_syswrap/syswrap-generic.c trunk/coregrind/m_syswrap/syswrap-linux.c trunk/coregrind/m_syswrap/syswrap-main.c trunk/coregrind/m_syswrap/syswrap-ppc32-linux.c trunk/coregrind/m_syswrap/syswrap-ppc64-linux.c trunk/coregrind/m_syswrap/syswrap-x86-linux.c trunk/coregrind/m_transtab.c trunk/coregrind/m_ume/elf.c trunk/coregrind/m_ume/main.c trunk/coregrind/m_ume/script.c trunk/coregrind/m_vki.c trunk/coregrind/pub_core_libcfile.h trunk/coregrind/pub_core_libcsignal.h trunk/coregrind/pub_core_machine.h trunk/coregrind/pub_core_signals.h trunk/coregrind/pub_core_syscall.h trunk/coregrind/pub_core_syswrap.h trunk/coregrind/pub_core_trampoline.h trunk/coregrind/pub_core_vki.h trunk/exp-ptrcheck/h_main.c trunk/include/pub_tool_basics.h trunk/include/pub_tool_libcfile.h trunk/include/vki/vki-amd64-linux.h trunk/include/vki/vki-ppc32-linux.h trunk/include/vki/vki-ppc64-linux.h trunk/include/vki/vki-x86-linux.h trunk/massif/ms_main.c trunk/memcheck/tests/unit_libcbase.c [... diff too large to include ...] |
|
From: <sv...@va...> - 2009-05-18 00:23:19
|
Author: njn
Date: 2009-05-18 01:20:41 +0100 (Mon, 18 May 2009)
New Revision: 9875
Log:
Add some missing __extension__ attributes. Fixes #192954.
Modified:
branches/VALGRIND_3_4_BRANCH/include/valgrind.h
Modified: branches/VALGRIND_3_4_BRANCH/include/valgrind.h
===================================================================
--- branches/VALGRIND_3_4_BRANCH/include/valgrind.h 2009-05-17 23:09:28 UTC (rev 9874)
+++ branches/VALGRIND_3_4_BRANCH/include/valgrind.h 2009-05-18 00:20:41 UTC (rev 9875)
@@ -3880,6 +3880,7 @@
/* Return 1 if a mempool exists, else 0. */
#define VALGRIND_MEMPOOL_EXISTS(pool) \
+ __extension__ \
({unsigned int _qzz_res; \
VALGRIND_DO_CLIENT_REQUEST(_qzz_res, 0, \
VG_USERREQ__MEMPOOL_EXISTS, \
@@ -3889,6 +3890,7 @@
/* Mark a piece of memory as being a stack. Returns a stack id. */
#define VALGRIND_STACK_REGISTER(start, end) \
+ __extension__ \
({unsigned int _qzz_res; \
VALGRIND_DO_CLIENT_REQUEST(_qzz_res, 0, \
VG_USERREQ__STACK_REGISTER, \
|
--- branches/DARWIN/coregrind/m_signals.c 2009-05-18 02:12:08 UTC (rev 9876)
+++ branches/DARWIN/coregrind/m_signals.c 2009-05-18 02:27:01 UTC (rev 9877)
@@ -251,16 +251,16 @@
/* ------ Macros for pulling stuff out of ucontexts ------ */
/* Q: what does UCONTEXT_SYSCALL_SYSRES do? A: let's suppose the
machine context (uc) reflects the situation that a syscall had just
completed, quite literally -- that is, that the program counter was
now at the instruction following the syscall. (or we're slightly
downstream, but we're sure no relevant register has yet changed
- value.) Then UCONTEXT_SYSCALL_SYSRES returns a SysRes reflecting
+ value.) Then VG_UCONTEXT_SYSCALL_SYSRES returns a SysRes reflecting
the result of the syscall; it does this by fishing relevant bits of
the machine state out of the uc. Of course if the program counter
was somewhere else entirely then the result is likely to be
- meaningless, so the caller of UCONTEXT_SYSCALL_SYSRES has to be
+ meaningless, so the caller of VG_UCONTEXT_SYSCALL_SYSRES has to be
very careful to pay attention to the results only when it is sure
that the said constraint on the program counter is indeed valid. */
#if defined(VGP_x86_linux)
@@ -1158,16 +1158,16 @@
vki_sigset_t* oldset )
{
switch(how) {
- case VKI_SIG_BLOCK:
- case VKI_SIG_UNBLOCK:
- case VKI_SIG_SETMASK:
- vg_assert(VG_(is_valid_tid)(tid));
- do_setmask ( tid, how, set, oldset );
- return VG_(mk_SysRes_Success)( 0 );
+ case VKI_SIG_BLOCK:
+ case VKI_SIG_UNBLOCK:
+ case VKI_SIG_SETMASK:
+ vg_assert(VG_(is_valid_tid)(tid));
+ do_setmask ( tid, how, set, oldset );
+ return VG_(mk_SysRes_Success)( 0 );
- default:
- VG_DMSG("sigprocmask: unknown 'how' field %d", how);
- return VG_(mk_SysRes_Error)( VKI_EINVAL );
+ default:
+ VG_DMSG("sigprocmask: unknown 'how' field %d", how);
+ return VG_(mk_SysRes_Error)( VKI_EINVAL );
}
}
@@ -1432,39 +1432,39 @@
vg_assert(VG_(is_running_thread)(tid));
switch(sigNo) {
- case VKI_SIGQUIT: /* core */
- case VKI_SIGILL: /* core */
- case VKI_SIGABRT: /* core */
- case VKI_SIGFPE: /* core */
- case VKI_SIGSEGV: /* core */
- case VKI_SIGBUS: /* core */
- case VKI_SIGTRAP: /* core */
- case VKI_SIGXCPU: /* core */
- case VKI_SIGXFSZ: /* core */
- terminate = True;
- core = True;
- break;
+ case VKI_SIGQUIT: /* core */
+ case VKI_SIGILL: /* core */
+ case VKI_SIGABRT: /* core */
+ case VKI_SIGFPE: /* core */
+ case VKI_SIGSEGV: /* core */
+ case VKI_SIGBUS: /* core */
+ case VKI_SIGTRAP: /* core */
+ case VKI_SIGXCPU: /* core */
+ case VKI_SIGXFSZ: /* core */
+ terminate = True;
+ core = True;
+ break;
- case VKI_SIGHUP: /* term */
- case VKI_SIGINT: /* term */
- case VKI_SIGKILL: /* term - we won't see this */
- case VKI_SIGPIPE: /* term */
- case VKI_SIGALRM: /* term */
- case VKI_SIGTERM: /* term */
- case VKI_SIGUSR1: /* term */
- case VKI_SIGUSR2: /* term */
- case VKI_SIGIO: /* term */
-# if defined(VKI_SIGPWR)
- case VKI_SIGPWR: /* term */
-# endif
- case VKI_SIGSYS: /* term */
- case VKI_SIGPROF: /* term */
- case VKI_SIGVTALRM: /* term */
-# if defined(VKI_SIGRTMIN) && defined(VKI_SIGRTMAX)
- case VKI_SIGRTMIN ... VKI_SIGRTMAX: /* term */
-# endif
- terminate = True;
- break;
+ case VKI_SIGHUP: /* term */
+ case VKI_SIGINT: /* term */
+ case VKI_SIGKILL: /* term - we won't see this */
+ case VKI_SIGPIPE: /* term */
+ case VKI_SIGALRM: /* term */
+ case VKI_SIGTERM: /* term */
+ case VKI_SIGUSR1: /* term */
+ case VKI_SIGUSR2: /* term */
+ case VKI_SIGIO: /* term */
+# if defined(VKI_SIGPWR)
+ case VKI_SIGPWR: /* term */
+# endif
+ case VKI_SIGSYS: /* term */
+ case VKI_SIGPROF: /* term */
+ case VKI_SIGVTALRM: /* term */
+# if defined(VKI_SIGRTMIN) && defined(VKI_SIGRTMAX)
+ case VKI_SIGRTMIN ... VKI_SIGRTMAX: /* term */
+# endif
+ terminate = True;
+ break;
}
vg_assert(!core || (core && terminate));
Modified: branches/DARWIN/coregrind/m_syscall.c
@@ -251,16 +251,16 @@
/* ------ Macros for pulling stuff out of ucontexts ------ */
-/* Q: what does UCONTEXT_SYSCALL_SYSRES do? A: let's suppose the
+/* Q: what does VG_UCONTEXT_SYSCALL_SYSRES do? A: let's suppose the
machine context (uc) reflects the situation that a syscall had just
completed, quite literally -- that is, that the program counter was
===================================================================